Class: Shellplay::Config
- Inherits:
-
ConfigStruct
- Object
- ConfigStruct
- Shellplay::Config
- Includes:
- Cliprompt
- Defined in:
- lib/shellplay/config.rb
Instance Method Summary collapse
Instance Method Details
#set_defaults ⇒ Object
9 10 11 12 |
# File 'lib/shellplay/config.rb', line 9 def set_defaults default :basedir, File.join(ENV['HOME'], '.shellplay') super end |
#setup ⇒ Object
14 15 16 17 18 19 20 |
# File 'lib/shellplay/config.rb', line 14 def setup values = {} output.puts Paint['Create a new shellplay configuration:', :blue] values['editor'] = guess 'EDITOR', 'What is the path to launch your text editor?', 'vim' values['prompt'] = ask 'What is the default prompt you want to use?' write values end |